==> apache-pulsar-2.11.1-src.tar.gz: apache-pulsar-2.11.1-src/pulsar-client/src/main/java/org/apache/pulsar/client/impl/UnAckedTopicMessageRedeliveryTracker.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.pulsar.client.impl;

import java.util.HashSet;
import java.util.Iterator;
import java.util.Map.Entry;
import org.apache.pulsar.client.api.MessageId;
import org.apache.pulsar.client.impl.conf.ConsumerConfigurationData;

public class UnAckedTopicMessageRedeliveryTracker extends UnAckedMessageRedeliveryTracker {

    public UnAckedTopicMessageRedeliveryTracker(PulsarClientImpl client, ConsumerBase<?> consumerBase,
                                                ConsumerConfigurationData<?> conf) {
        super(client, consumerBase, conf);
    }

    public int removeTopicMessages(String topicName) {
        writeLock.lock();
        try {
            int removed = 0;
            Iterator<Entry<UnackMessageIdWrapper, HashSet<UnackMessageIdWrapper>>> iterator =
                    redeliveryMessageIdPartitionMap.entrySet().iterator();
            while (iterator.hasNext()) {
                Entry<UnackMessageIdWrapper, HashSet<UnackMessageIdWrapper>> entry = iterator.next();
                UnackMessageIdWrapper messageIdWrapper = entry.getKey();
                MessageId messageId = messageIdWrapper.getMessageId();
                if (messageId instanceof TopicMessageIdImpl
                        && ((TopicMessageIdImpl) messageId).getTopicPartitionName().contains(topicName)) {
                    HashSet<UnackMessageIdWrapper> exist = redeliveryMessageIdPartitionMap.get(messageIdWrapper);
                    entry.getValue().remove(messageIdWrapper);
                    iterator.remove();
                    messageIdWrapper.recycle();
                    removed++;
                }
            }

            Iterator<MessageId> iteratorAckTimeOut = ackTimeoutMessages.keySet().iterator();
            while (iterator.hasNext()) {
                MessageId messageId = iteratorAckTimeOut.next();
                if (messageId instanceof TopicMessageIdImpl
                        && ((TopicMessageIdImpl) messageId).getTopicPartitionName().contains(topicName)) {
                    iterator.remove();
                    removed++;
                }
            }
            return removed;
        } finally {
            writeLock.unlock();
        }
    }

}

==> apache-pulsar-3.0.9-src.tar.gz: apache-pulsar-3.0.9-src/pulsar-client/src/main/java/org/apache/pulsar/client/impl/UnAckedTopicMessageRedeliveryTracker.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.pulsar.client.impl;

import java.util.HashSet;
import java.util.Iterator;
import java.util.Map.Entry;
import org.apache.pulsar.client.api.MessageId;
import org.apache.pulsar.client.api.TopicMessageId;
import org.apache.pulsar.client.impl.conf.ConsumerConfigurationData;

public class UnAckedTopicMessageRedeliveryTracker extends UnAckedMessageRedeliveryTracker {

    public UnAckedTopicMessageRedeliveryTracker(PulsarClientImpl client, ConsumerBase<?> consumerBase,
                                                ConsumerConfigurationData<?> conf) {
        super(client, consumerBase, conf);
    }

    public int removeTopicMessages(String topicName) {
        writeLock.lock();
        try {
            int removed = 0;
            Iterator<Entry<UnackMessageIdWrapper, HashSet<UnackMessageIdWrapper>>> iterator =
                    redeliveryMessageIdPartitionMap.entrySet().iterator();
            while (iterator.hasNext()) {
                Entry<UnackMessageIdWrapper, HashSet<UnackMessageIdWrapper>> entry = iterator.next();
                UnackMessageIdWrapper messageIdWrapper = entry.getKey();
                MessageId messageId = messageIdWrapper.getMessageId();
                if (messageId instanceof TopicMessageId
                        && ((TopicMessageId) messageId).getOwnerTopic().contains(topicName)) {
                    HashSet<UnackMessageIdWrapper> exist = redeliveryMessageIdPartitionMap.get(messageIdWrapper);
                    entry.getValue().remove(messageIdWrapper);
                    iterator.remove();
                    messageIdWrapper.recycle();
                    removed++;
                }
            }

            Iterator<MessageId> iteratorAckTimeOut = ackTimeoutMessages.keySet().iterator();
            while (iterator.hasNext()) {
                MessageId messageId = iteratorAckTimeOut.next();
                if (messageId instanceof TopicMessageId
                        && ((TopicMessageId) messageId).getOwnerTopic().contains(topicName)) {
                    iterator.remove();
                    removed++;
                }
            }
            return removed;
        } finally {
            writeLock.unlock();
        }
    }

}
